@@ -1,10 +1,10 @@
 package Net::DNS::SEC::ECDSA;
 
 #
-# $Id: ECDSA.pm 1616 2018-01-22 08:54:52Z willem $
+# $Id: ECDSA.pm 1619 2018-01-24 08:24:17Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1616 $)[1];
+$VERSION = (qw$LastChangedRevision: 1619 $)[1];
 
 
 =head1 NAME
@@ -77,25 +77,28 @@ sub sign {
 
 	my $keybin = decode_base64( $private->PrivateKey );
 
-	my $eckey = Net::DNS::SEC::libcrypto::EC_KEY_dup(_curve($NID));
+	my $eckey = Net::DNS::SEC::libcrypto::EC_KEY_dup( _curve($NID) );
 	Net::DNS::SEC::libcrypto::EC_KEY_set_private_key( $eckey, $keybin );
 
+	my $size = length $keybin;
 	$keybin = $digest;					# destroy private key
 
 	my $sig = Net::DNS::SEC::libcrypto::ECDSA_do_sign( $digest, $eckey );
 
 	Net::DNS::SEC::libcrypto::EC_KEY_free($eckey);		# destroy private key
 
-	return unless $sig;					# uncoverable branch
-	my ( $r, $s ) = Net::DNS::SEC::libcrypto::ECDSA_SIG_get0($sig);
+	my $z;
+	if ($sig) {						# uncoverable branch false
+		my ( $r, $s ) = Net::DNS::SEC::libcrypto::ECDSA_SIG_get0($sig);
+
+		# both the R and S parameters need to be zero padded:
+		my $Rpad = $size - length($r);
+		my $Spad = $size - length($s);
+		$z = pack "x$Rpad a* x$Spad a*", $r, $s;
+	}
 
 	Net::DNS::SEC::libcrypto::ECDSA_SIG_free($sig);
-
-	# both the R and S parameters need to be zero padded:
-	my $size = length $keybin;
-	my $Rpad = $size - length($r);
-	my $Spad = $size - length($s);
-	pack "x$Rpad a* x$Spad a*", $r, $s;
+	return $z;
 }
 
 
@@ -112,10 +115,12 @@ sub verify {
 	my $keylen = length($keybin) >> 1;
 	my ( $x, $y ) = unpack "a$keylen a*", $keybin;
 
-	my $eckey = Net::DNS::SEC::libcrypto::EC_KEY_dup(_curve($NID));
+	return unless $sigbin;
+
+	my $eckey = Net::DNS::SEC::libcrypto::EC_KEY_dup( _curve($NID) );
 	Net::DNS::SEC::libcrypto::EC_KEY_set_public_key_affine_coordinates( $eckey, $x, $y );
 
-	my $siglen = length( $sigbin || return ) >> 1;			# signature
+	my $siglen = length($sigbin) >> 1;			# signature
 	my ( $r, $s ) = unpack( "a$siglen a*", $sigbin );
 
 	my $sig = Net::DNS::SEC::libcrypto::ECDSA_SIG_new();
